.. _interactive-notebooks:

**************************
Interactive Mode Notebooks
**************************

We present some notebooks demonstrating usage of RAIL in interactive mode. 

===============
Getting Started
===============

There are two recommended starting points:

1. If you just want to get some photometric redshifts, then `Using Photometry to Estimate Photometric Redshifts <https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/interactive_examples/rendered/interactive_examples/Using_Photometry_to_Estimate_Photometric_Redshifts.html>`_ should cover most of of what you need. 
2. If you are looking for a more general introduction to all of RAIL, start with `Estimating Photometric Redshifts with RAIL Stages and Comparing Results for Different Parameters <https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/interactive_examples/rendered/estimation_examples/Estimating_Redshifts_and_Comparing_Results_for_Different_Parameters.html>`_.

If you'd like to go even more in-depth into creating data, take a look at `Exploring the Effects of Degraders <https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/interactive_examples/rendered/creation_examples/Exploring_the_Effects_of_Degraders.html>`_. 
For a less-detailed overview of a full RAIL workflow, there's the `Goldenspike
<https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/interactive_examples/rendered/goldenspike_examples/Goldenspike.html>`_
notebook. 

=================
Exploring Further
=================

There are many more notebooks that you can explore, if you're looking for 
something specific. They are split up into four main categories:

* `Core Examples <https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/core_notebooks.html>`_: These notebooks provide examples of some of the utilities and base functionalities of RAIL. 
* `Creation Examples <https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/creation_notebooks.html>`_: These notebooks cover how to create realistic simulated photometric data with RAIL.
* `Estimation Examples <https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/estimation_notebooks.html>`_: These notebooks show how to use the various estimation algorithms that are currently a part of RAIL.
* `Evaluation Examples <https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/evaluation_notebooks.html>`_: These notebooks cover how to use the evaluation algorithms that are included with RAIL to get metrics on how well the estimated photometric redshifts represent the true redshifts.

